#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-2meBeW6DmawleaNhSlPWJ
key:                  mono-traversable-instances-0.1.1.0-2meBeW6DmawleaNhSlPWJ
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  a296307aaef16f5cfbf5e688a7d60b5d
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/mono-traversable-instances-0.1.1.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable-instances
hs-libraries:         HSmono-traversable-instances-0.1.1.0-2meBeW6DmawleaNhSlPWJ
depends:
    base-4.18.2.1 comonad-5.0.9-1SlrkjN0ZqRKKhAWtB7vbo containers-0.6.7
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    dlist-instances-0.1.1.1-CJKDuS8fq9PBqGXaYa3dlm
    mono-traversable-1.0.21.0-7ChyVwWLZG7AsyZXWqg45E
    semigroupoids-6.0.2-KjN8okTTJFX21iduCaon9n transformers-0.6.1.0
    vector-instances-3.4.3-IQGtwz2NKvjLB1YMdTFdp8

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

